@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# MySqlPy V1.5.1
+# MySqlPy V1.5.2
 # Author: Luca.Canali@cern.ch
 # 
 #
@@ -186,7 +186,7 @@ def run():
                 pass
             my.do_connect(connectstring)
         for arg in sys.argv[1:]:
-            if my.onecmd(arg, assumeComplete=True) == my._STOP_AND_EXIT:
+            if my.onecmd(arg) == my._STOP_AND_EXIT:
                 return
     except IndexError:
         pass
