@@ -497,10 +497,6 @@ class sqlpyPlus(sqlpython.sqlpython):
     rowlimitPattern = pyparsing.Word(pyparsing.nums)('rowlimit')
     terminators = '; \\C \\t \\i \\p \\l \\L \\b '.split() + output_templates.keys()
 
-    def expandSelect(self, arg):
-        #w + Optional(CaselessKeyword('AS')) + Optional(w ^ dblQuotedString) + (CaselessKeyword('FROM') ^ ',')
-        return arg
-    
     def do_select(self, arg, bindVarsIn=None, terminator=None):
         """Fetch rows from a table.
 
@@ -518,7 +514,6 @@ class sqlpyPlus(sqlpython.sqlpython):
             rowlimit = 0
             print "Specify desired number of rows after terminator (not '%s')" % arg.parsed.suffix
         self.varsUsed = findBinds(arg, self.binds, bindVarsIn)
-        arg = self.expandSelect(arg)
         self.curs.execute('select ' + arg, self.varsUsed)
         self.rows = self.curs.fetchmany(min(self.maxfetch, (rowlimit or self.maxfetch)))
         self.rc = self.curs.rowcount
@@ -843,7 +838,7 @@ class sqlpyPlus(sqlpython.sqlpython):
                 statekeeper.restore()
 
     def do_exec(self, arg):
-        if arg[0] == ':':
+        if arg.startswith(':'):
             self.do_setbind(arg[1:])
         else:
             varsUsed = findBinds(arg, self.binds, {})
@@ -930,6 +925,10 @@ class sqlpyPlus(sqlpython.sqlpython):
                 traceback.print_exc(file=sys.stdout)                
 
     def do_refs(self, arg):
+        '''Lists referential integrity (foreign key constraints) on an object.'''
+        
+        if not arg.strip():
+            print 'Usage: refs (table name)'
         result = []
         (type, owner, table_name) = self.resolve(arg.upper())        
         self.curs.execute("""SELECT constraint_name, r_owner, r_constraint_name 
